diff -ru a/modules/video_output/x11/x11.c b/modules/video_output/x11/x11.c
--- a/modules/video_output/x11/x11.c	2008-10-28 00:04:49.000000000 +0100
+++ b/modules/video_output/x11/x11.c	2008-11-04 00:01:04.000000000 +0100
@@ -66,6 +66,16 @@
     "Screen to use in fullscreen mode. For instance " \
     "set it to 0 for first screen, 1 for the second.")
 
+#define X11_EVENT_TEXT N_("key and mouse event handling at X11 plugin level.")
+#define X11_EVENT_LONGTEXT N_( \
+    "This parameter accepts values : 1 (No event handling), " \
+    "2 (event handling only for fullscreen) or 3 (full event handling support). "  \
+    "Full event handling support is the default value.") 
+
+static const int pi_x11_event_values[] = { 1, 2, 3 };
+static const char *const ppsz_x11_event_descriptions[] =
+     { N_("None"), N_("Fullscreen-Only"), N_("FullSupport") };
+
 vlc_module_begin();
     set_shortname( "X11" );
     set_category( CAT_VIDEO );
@@ -78,6 +88,8 @@
 #ifdef HAVE_XINERAMA
     add_integer ( "x11-xineramascreen", -1, NULL, SCREEN_TEXT, SCREEN_LONGTEXT, true );
 #endif
+    add_integer( "x11-event", 3, NULL, X11_EVENT_TEXT, X11_EVENT_LONGTEXT, true );
+        change_integer_list( pi_x11_event_values, ppsz_x11_event_descriptions, NULL );
     set_description( N_("X11 video output") );
     set_capability( "video output", 70 );
     set_callbacks( Activate, Deactivate );
diff -ru a/modules/video_output/x11/xcommon.c b/modules/video_output/x11/xcommon.c
--- a/modules/video_output/x11/xcommon.c	2008-10-28 00:04:49.000000000 +0100
+++ b/modules/video_output/x11/xcommon.c	2008-11-03 20:57:51.000000000 +0100
@@ -1790,10 +1790,22 @@
         }
     } while( !( b_expose && b_configure_notify && b_map_notify ) );
 
-    XSelectInput( p_vout->p_sys->p_display, p_win->base_window,
-                  StructureNotifyMask | KeyPressMask |
-                  ButtonPressMask | ButtonReleaseMask |
-                  PointerMotionMask );
+    /* key and mouse events handling depending on --x11-event option    
+     *      - activated by default
+     *      - desactivated if option provided by user is :
+     *           value 1 (None)
+     *        or value 2 (Fullscreen-Only) and condition not met
+     */
+    int i_x11_event = var_CreateGetInteger( p_vout, "x11-event" );
+    bool b_x11_event = (    ( i_x11_event == 1 )
+                         || ( i_x11_event == 2  && !p_vout->b_fullscreen )
+                       ) ? false : true;
+       
+    if ( b_x11_event )
+        XSelectInput( p_vout->p_sys->p_display, p_win->base_window,
+                      StructureNotifyMask | KeyPressMask |
+                      ButtonPressMask | ButtonReleaseMask |
+                      PointerMotionMask );
 
 #ifdef MODULE_NAME_IS_x11
     if( XDefaultDepth(p_vout->p_sys->p_display, p_vout->p_sys->i_screen) == 8 )
